import numpy as np
import os
import gdal
import glob
import re
import sys

class Tiff_2_Lerc(object):
    def __init__(self, input_dir: str, min_level: int, max_level: int, output_dir: str):
        if input_dir[-1] != '/' or output_dir[-1] != '/':
            print('path must be ended with \'/\' !!!')
            exit(0)
        self.input_dir = input_dir
        self.min_level = min_level
        self.max_level = max_level
        self.output_dir = output_dir
        '''
        input: 输入需要转换的tiff存在的目录或者上级目录等
        min_level: 切片的最小层级
        max_level: 切片的最大层级
        output: 输出的目录，内部的子目录结构和输入的目录结构一致
        '''


    # ===================== tiff转 lerc ===================================
    def tiff_lerc(self, inputtif: str , outputpath :str):
        '''
        :param inputtif: 需要切片的tiff
        :param outputpath: 切片后的tiff和lerc目录
        :return: 切片后的tiff和lerc
        '''
        if outputpath[-1] != '/':
            print('path must be ended with \'/\' !!!')
            exit(0)
            pass
        # temp_path = '/massdata2/gago_developers/tmp'
        os.system('python /home/gago_developers/cropdes/tifftiler.py %s %s %s %s'
                  %(inputtif, str(self.min_level), str(self.max_level), outputpath))

        cmd = '/home/gago_developers/LercTiler/tif2lerc-cpp/lerctiler --input '+ outputpath +' --output ' + outputpath+' --band 1 --maxzerror 0.1'
        os.system(cmd)
        # os.rmdir('%s/5' %temp_path)
        # os.rmdir('%s/4' %temp_path)
    def convert(self):
        '''
        对目录下所有的tiff进行切片
        :return:
        '''
        mother_dir = self.input_dir
        out_dir = self.output_dir
        path_name = []
        for dir_path, dir_name, filename in os.walk(mother_dir):
            if filename != []:
                # print(dir_path, dir_name, filename)
                for k in filename:
                    # print(k)
                    if ('.tiff' in k) or ('.tif' in k):
                        # print(dir_path+ k)
                        full_name = '%s/%s' % (dir_path, k)
                        print(full_name)
                        out_name = (full_name.split('.')[0]).replace(mother_dir, out_dir) + '/'
                        path_name.append(out_name)
                        print(out_name)
                        self.tiff_lerc(full_name, out_name)
        print('input path has ', len(path_name), 'tiff file.')
        # pass


def main():
    '''
    usage: python multi_tiff2lerc.py [输入数据的上级目录] [最小切片层级] [最大切片层级] [输出目录]
    example: python multi_tiff2lerc.py /massdata2/liuzhe/tile/ 4 14 /massdata2/liuzhe/out/
    NOTE1: 输入和输出目录后缀需要有'/'
    NOTE2：输出的子目录和输入的子目录下的目录结构是一致的
    :return: 切片后的tiff和lerc
    '''
    input_path, min_level, max_level, output_path = sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4]
    xx = Tiff_2_Lerc(input_dir=input_path, min_level=min_level, max_level=max_level, output_dir=output_path)
    xx.convert()


if __name__ == "__main__":
    main()


